==> kadu_3.0~rc1.orig.tar.bz2: kadu-3.0-rc1/plugins/tabs/translations/tabs_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>@default</name>
    <message>
        <source>Tabs</source>
        <translation>Onglets</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Général</translation>
    </message>
    <message>
        <source>Look</source>
        <translation>Apparence</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Raccourcis</translation>
    </message>
    <message>
        <source>Move tab left</source>
        <translation>Déplacer l&apos;onglet à gauche</translation>
    </message>
    <message>
        <source>Move tab right</source>
        <translation>Déplacer l&apos;onglet à droite</translation>
    </message>
    <message>
        <source>Switch to previous tab</source>
        <translation>Aller à l&apos;onglet précédent</translation>
    </message>
    <message>
        <source>Switch to next tab</source>
        <translation>Aller à l&apos;onglet suivant</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>Conversation</translation>
    </message>
    <message>
        <source>Enable tabs in chat window</source>
        <translation>Activer les onglets dans la fenêtre de conversation</translation>
    </message>
    <message>
        <source>With this option, each chat will be opened in a separate tab in single window</source>
        <translation>Avec cette option, chaque conversation va s&apos;ouvrir dans une fenêtre séparé.</translation>
    </message>
    <message>
        <source>Closing window closes current tab only</source>
        <translation>Fermer la fenêtre ferme seulement l&apos;onglet courant</translation>
    </message>
    <message>
        <source>When enabled, closing chat window will cause closing only current tab, instead of all tabs and the window itself</source>
        <translation>Quand activé, fermer la fenêtre de conversation ne fermera uniquement que l&apos;onglet courant au lieu de fermer la fenêtre</translation>
    </message>
    <message>
        <source>Tab bar position</source>
        <translation>Position de la barre d&apos;onglets</translation>
    </message>
    <message>
        <source>Choose where you want the tab bar to be placed in chat window</source>
        <translation>Choisissez où vous voulez positionner la barre d&apos;onglets dans la fenêtre de conversation</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Haut</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Bas</translation>
    </message>
    <message>
        <source>Behavior</source>
        <translation>Comportement</translation>
    </message>
    <message>
        <source>Reopen closed tab</source>
        <translation>Ré-ouvrir l&apos;onglet fermé</translation>
    </message>
    <message>
        <source>Show &apos;Open chat&apos; button</source>
        <translation>Afficher le bouton &apos;Conversation ouverte&apos;</translation>
    </message>
    <message>
        <source>Show common &apos;Close Tab&apos; button on tab bar</source>
        <translation>Afficher le bouton commun &apos;Fermer Onglet&apos; sur la barre d&apos;onglet</translation>
    </message>
    <message>
        <source>Show &apos;Close&apos; button on each tab</source>
        <translation>Afficher le bouton &apos;Fermer&apos; sur chaque onglet</translation>
    </message>
</context>
<context>
    <name>TabWidget</name>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>New message received, close window anyway?</source>
        <translation>Nouveau message reçu, fermer le fenêtre tout de même ?</translation>
    </message>
    <message>
        <source>Recent Chats</source>
        <translation>Conversation Récentes</translation>
    </message>
    <message>
        <source>Open Chat with...</source>
        <translation>Ouvrir la Conversation avec...</translation>
    </message>
    <message>
        <source>Tabs</source>
        <translation>Onglets</translation>
    </message>
    <message>
        <source>Close Tab</source>
        <translation>Fermer Onglet</translation>
    </message>
    <message>
        <source>Close window</source>
        <translation>Fermer la fenêtre</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
</context>
<context>
    <name>TabsManager</name>
    <message>
        <source>Chat in New Window</source>
        <translation>Discuter dans une nouvelle fenêtre</translation>
    </message>
    <message>
        <source>Chat in New Tab</source>
        <translation>Discuter dans un nouvelle onglet</translation>
    </message>
    <message>
        <source>Attach Chat to Tabs</source>
        <translation>Attacher une conversation à des onglets</translation>
    </message>
    <message>
        <source>Detach</source>
        <translation>Détacher</translation>
    </message>
    <message>
        <source>Detach all</source>
        <translation>Tout détacher</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Fermer</translation>
    </message>
    <message>
        <source>Close all</source>
        <translation>Fermer tous</translation>
    </message>
    <message>
        <source>Close other tabs</source>
        <translation>Fermer les autres onglets</translation>
    </message>
    <message>
        <source>Reopen closed tab</source>
        <translation>Ré-ouvrir l&apos;onglet fermé</translation>
    </message>
</context>
</TS>

==> kadu_4.1.orig.tar.bz2: kadu-4.1/plugins/tabs/translations/tabs_fr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="fr" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>Tabs</source>
        <translation>Onglets</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Général</translation>
    </message>
    <message>
        <source>Look</source>
        <translation>Apparence</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Raccourcis</translation>
    </message>
    <message>
        <source>Move tab left</source>
        <translation>Déplacer l&apos;onglet à gauche</translation>
    </message>
    <message>
        <source>Move tab right</source>
        <translation>Déplacer l&apos;onglet à droite</translation>
    </message>
    <message>
        <source>Switch to previous tab</source>
        <translation>Aller à l&apos;onglet précédent</translation>
    </message>
    <message>
        <source>Switch to next tab</source>
        <translation>Aller à l&apos;onglet suivant</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>Conversation</translation>
    </message>
    <message>
        <source>Enable tabs in chat window</source>
        <translation>Activer les onglets dans la fenêtre de conversation</translation>
    </message>
    <message>
        <source>With this option, each chat will be opened in a separate tab in single window</source>
        <translation>Avec cette option, chaque conversation va s&apos;ouvrir dans une fenêtre séparé.</translation>
    </message>
    <message>
        <source>Closing window closes current tab only</source>
        <translation>Fermer la fenêtre ferme seulement l&apos;onglet courant</translation>
    </message>
    <message>
        <source>When enabled, closing chat window will cause closing only current tab, instead of all tabs and the window itself</source>
        <translation>Quand activé, fermer la fenêtre de conversation ne fermera uniquement que l&apos;onglet courant au lieu de fermer la fenêtre</translation>
    </message>
    <message>
        <source>Tab bar position</source>
        <translation>Position de la barre d&apos;onglets</translation>
    </message>
    <message>
        <source>Choose where you want the tab bar to be placed in chat window</source>
        <translation>Choisissez où vous voulez positionner la barre d&apos;onglets dans la fenêtre de conversation</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Haut</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Bas</translation>
    </message>
    <message>
        <source>Behavior</source>
        <translation>Comportement</translation>
    </message>
    <message>
        <source>Reopen closed tab</source>
        <translation>Ré-ouvrir l&apos;onglet fermé</translation>
    </message>
    <message>
        <source>Show &apos;Open chat&apos; button</source>
        <translation>Afficher le bouton &apos;Conversation ouverte&apos;</translation>
    </message>
    <message>
        <source>Show common &apos;Close Tab&apos; button on tab bar</source>
        <translation>Afficher le bouton commun &apos;Fermer Onglet&apos; sur la barre d&apos;onglet</translation>
    </message>
    <message>
        <source>Show &apos;Close&apos; button on each tab</source>
        <translation>Afficher le bouton &apos;Fermer&apos; sur chaque onglet</translation>
    </message>
</context>
<context>
    <name>TabWidget</name>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>New message received, close window anyway?</source>
        <translation>Nouveau message reçu, fermer le fenêtre tout de même ?</translation>
    </message>
    <message>
        <source>Recent Chats</source>
        <translation>Conversation Récentes</translation>
    </message>
    <message>
        <source>Open Chat with...</source>
        <translation>Ouvrir la Conversation avec...</translation>
    </message>
    <message>
        <source>Tabs</source>
        <translation>Onglets</translation>
    </message>
    <message>
        <source>Close Tab</source>
        <translation>Fermer Onglet</translation>
    </message>
    <message>
        <source>Close window</source>
        <translation>Fermer la fenêtre</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
</context>
<context>
    <name>TabsManager</name>
    <message>
        <source>Chat in New Window</source>
        <translation>Discuter dans une nouvelle fenêtre</translation>
    </message>
    <message>
        <source>Chat in New Tab</source>
        <translation>Discuter dans un nouvelle onglet</translation>
    </message>
    <message>
        <source>Attach Chat to Tabs</source>
        <translation>Attacher une conversation à des onglets</translation>
    </message>
    <message>
        <source>Detach</source>
        <translation>Détacher</translation>
    </message>
    <message>
        <source>Detach all</source>
        <translation>Tout détacher</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Fermer</translation>
    </message>
    <message>
        <source>Close all</source>
        <translation>Fermer tous</translation>
    </message>
    <message>
        <source>Close other tabs</source>
        <translation>Fermer les autres onglets</translation>
    </message>
    <message>
        <source>Reopen closed tab</source>
        <translation>Ré-ouvrir l&apos;onglet fermé</translation>
    </message>
</context>
</TS>
